@@ -1,10 +1,7 @@
 """Plotting utilities.
 """
-import numpy as np
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 
-import astropy.coordinates as coord
 from astropy.units import degree
 
 
@@ -18,8 +15,27 @@ def ra_dec(skycoord):
     return ra, dec
 
 
-def projection_axes(projection='aitoff', **figargs):
+def projection_axes(projection="aitoff", **figargs):
     fig = plt.figure(**figargs)
     ax = fig.add_subplot(111, projection=projection)
-    ax.grid(color='lightgrey')
+    ax.grid(color="lightgrey")
+    return ax
+
+
+def plot_equatorial(
+    evts,
+    projection="aitoff",
+    ax=None,
+    marker="o",
+    markersize=4,
+    alpha=0.8,
+    adjust_subplots=True,
+    **kwargs
+):
+    ra, dec = ra_dec(evts)
+    if ax is None:
+        ax = projection_axes(projection=projection)
+    ax.plot(ra, dec, marker, markersize=markersize, alpha=alpha, **kwargs)
+    if adjust_subplots:
+        plt.subplots_adjust(top=0.95, bottom=0.0)
     return ax
